@@ -590,13 +590,6 @@ static void ath9k_hif_usb_rx_stream(struct hif_device_usb *hif_dev,
 			return;
 		}
 
-		if (pkt_len > 2 * MAX_RX_BUF_SIZE) {
-			dev_err(&hif_dev->udev->dev,
-				"ath9k_htc: invalid pkt_len (%x)\n", pkt_len);
-			RX_STAT_INC(skb_dropped);
-			return;
-		}
-
 		pad_len = 4 - (pkt_len & 0x3);
 		if (pad_len == 4)
 			pad_len = 0;
