@@ -28,6 +28,8 @@
 #define rhashtable_free_and_destroy LINUX_BACKPORT(rhashtable_free_and_destroy)
 #undef rhashtable_destroy
 #define rhashtable_destroy LINUX_BACKPORT(rhashtable_destroy)
+#undef __rht_bucket_nested
+#define __rht_bucket_nested LINUX_BACKPORT(__rht_bucket_nested)
 #undef rht_bucket_nested
 #define rht_bucket_nested LINUX_BACKPORT(rht_bucket_nested)
 #undef rht_bucket_nested_insert
